cobbler.modules.installation package
====================================

Submodules
----------

cobbler.modules.installation.post\_log module
---------------------------------------------

.. automodule:: cobbler.modules.installation.post_log
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.post\_power module
-----------------------------------------------

.. automodule:: cobbler.modules.installation.post_power
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.post\_puppet module
------------------------------------------------

.. automodule:: cobbler.modules.installation.post_puppet
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.post\_report module
------------------------------------------------

.. automodule:: cobbler.modules.installation.post_report
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.pre\_clear\_anamon\_logs module
------------------------------------------------------------

.. automodule:: cobbler.modules.installation.pre_clear_anamon_logs
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.pre\_log module
--------------------------------------------

.. automodule:: cobbler.modules.installation.pre_log
    :members:
    :undoc-members:
    :show-inheritance:

cobbler.modules.installation.pre\_puppet module
-----------------------------------------------

.. automodule:: cobbler.modules.installation.pre_puppet
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cobbler.modules.installation
    :members:
    :undoc-members:
    :show-inheritance:
